@@ -5,10 +5,13 @@ use strict;
 use warnings;
 use MRO::Compat;
 use Scalar::Util ();
+use TestLogger;
 
 use base qw/Catalyst Catalyst::Controller/;
 use Catalyst qw//;
 
+__PACKAGE__->log(TestLogger->new);
+
 sub execute {
     my $c = shift;
     my ( $class, $action ) = @_;
