@@ -1,6 +1,6 @@
 package ScriptTestApp::TraitFor::Script::Bar;
 use Moose::Role;
-use namespace::clean -except => [ 'meta' ];
+use namespace::autoclean;
 
 around run => sub {
     my ($orig, $self, @args) = @_;
